﻿// MZpack 3 Pro API demo
// Copyright © 2020 MZpack Co.
// www.mzpack.pro
// WARNING: to compile this sample in NinjaTrader 8 remove '#if APISAMPLE' and '#endif' directives
#if APISAMPLE
using System;
using NinjaTrader.Cbi;
using MZpack.NT8.Algo;

namespace NinjaTrader.NinjaScript.Strategies.MZpackAPISamples
{
    /// <summary>
    /// This class demonstrates using of MZpack.NT8.Algo.Strategy abstract class. 
    /// AlgoStrategy1 class is used in MZpackAlgoStrategy1 class.
    /// </summary>
    public class AlgoStrategy1 : MZpack.NT8.Algo.Strategy
    {
        int stopLossBarIdx = -1;  // Bar index when the last stop loss order triggered

        public AlgoStrategy1(string name, MZpackAlgoStrategy1 ninjaStrategy): base(name, ninjaStrategy)
        {
        }

        /// <summary>
        /// Custom filter on position open. 
        /// Implements 'No new entries on stop loss bar' logic.
        /// </summary>
        /// <param name="time"></param>
        /// <returns></returns>
        public override bool OnPositionOpenFilter(DateTime time) 
        {
            //resetPattern = false; // Don't reset current pattern. Pattern is reset on position open inside API

            if ((Pattern.Direction == ((MZpackAlgoStrategy1)MZpackStrategy).Position_Direction || ((MZpackAlgoStrategy1)MZpackStrategy).Position_Direction == SignalDirection.Any) &&
                MZpackStrategy.CurrentBar > stopLossBarIdx) // No entries on stop loss bar
            {
                stopLossBarIdx = -1; // reset stop loss bar index
                return true;
            }

            return false;
        }

        public override void OnOrderUpdate(Order order, OrderState orderState)
        {
            base.OnOrderUpdate(order, orderState);

            // Stop loss was triggered
            if (orderState == OrderState.Filled && order.Name == MZpack.NT8.Algo.Strategy.ORDER_NAME_STOPLOSS)
            {
                stopLossBarIdx = MZpackStrategy.CurrentBar;
            }
        }
    }
}
#endif