﻿// MZpack 3 Pro API demo
// Copyright © 2021 MZpack Co.
// www.mzpack.pro
// WARNING: to compile this sample in NinjaTrader 8 remove '#if APISAMPLE' and '#endif' directives
#if APISAMPLE
using System;
using System.Collections.Generic;
using MZpack;
using MZpack.NT8;
using MZpack.NT8.Algo;
using MZpack.NT8.Algo.Indicators;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using NinjaTrader.Gui;
using NinjaTrader.Data;

namespace NinjaTrader.NinjaScript.Strategies.MZpackAPISamples
{
    /// <summary>
    /// Demonstrates how to access data of MZpack mzVolumeProfile indicator (StrategyVolumeProfileIndicator class) with Minute accuracy.
    /// See installation folder for the source code.
    /// </summary>
    [CategoryOrder("Settings", 1)]
    public class DataAccess_mzVolumeProfile_MinuteAccuracy : MZpackStrategyBase
    {
        StrategyVolumeProfileIndicator volumePorfileIndicator;
        IVolumeProfile current;


        public DataAccess_mzVolumeProfile_MinuteAccuracy() : base()
        {
            // Set OnCreateIndicators delegate
            OnCreateIndicators = new OnCreateIndicatorsDelegate(CreateIndicators);
        }

        /// <summary>
        /// Create indicator here and return the list with one item as a result.
        /// </summary>
        /// <returns>Indicators list</returns>
        protected List<TickIndicator> CreateIndicators()
        {
            // Initialize new indicators list
            List<TickIndicator> indicators = new List<TickIndicator>();

            // Create StrategyFootprintIndicator instance 
            volumePorfileIndicator = new StrategyVolumeProfileIndicator(this, @"VolumeProfile")
            {
                // Override defaults if required
                Calculate = Calculate.OnBarClose, // Force Calculate OnBarClose for Minute accuracy
                ShowProfileType = ProfileType.VP,  // Volume profile only
                ProfileAccuracy = ProfileAccuracy.Minute,
                ProfileCreation = ProfileCreation.Session,
                POCMode = LevelMode.Developing,
                VAHVALMode = LevelMode.On,
                VWAPMode = VWAPMode.DynamicStdDev1,
                ProfileWidthPercentage = 20,
                Values1KDivider = false,

                // No stacked profiles
                StackedProfileCreation1 = ProfileCreation.None,
                StackedProfileCreation2 = ProfileCreation.None,
                StackedProfileCreation3 = ProfileCreation.None
            };

 
            // Add indicator to the list
            indicators.Add(volumePorfileIndicator);  

            return indicators;
        }

        protected override void OnStateChange()
        {
            // Base OnStateChange() call is required
            base.OnStateChange();

            lock (Sync) // Sync OnStateChange handler
            {
                if (State == State.SetDefaults)
                {
                    BarsRequiredToTrade = 1;

                    // To print data from hisotrical bars
                    EnableBacktesting = true;
                }
                else if (State == State.Configure)
                {
                    Calculate = Calculate.OnBarClose;  // The profile with Minute accuracy is updated OnBarClose
                }
            }
        }

        protected override void OnBarUpdate()
        {
            base.OnBarUpdate();

            // Process chart data series only
            if (BarsInProgress == 0)
            {
                IVolumeProfile last = volumePorfileIndicator.Profiles.LastOrDefault() as IVolumeProfile;

                if (last != null)
                {
                    // New session profile has been started
                    if (last != current)
                    {
                        // Print total values for the previous profile
                        if (current != null)
                        {
                            Print(string.Format("TOTALS Volume: {0}; Delta: {1}; High: {2}; Low: {3}", current.Volume, current.Delta, current.High, current.Low));
                            Print(""); // Delimiter between profiles
                        }
                    }

                    // Print profiles values for the current bar
                    Print(string.Format("{0} VAH: {1}; VAL: {2}; POC: {3}; VWAP: {4}", Time[0], last.VAH, last.VAL, last.POC, last.VWAP));

                    // Make last profile current
                    if (last != current)
                        current = last;
                }
            }
        }

    }
}
#endif